"""Add expense tracking tables and item price columns

Revision ID: ebbe5cdba808
Revises: d25788f63e2c
Create Date: 2025-04-02 23:51:31.432547

"""
from typing import Sequence, Union

from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision: str = 'ebbe5cdba808'
down_revision: Union[str, None] = 'd25788f63e2c'
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None


def upgrade() -> None:
    """Upgrade schema."""
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table('expense_records',
    sa.Column('id', sa.Integer(), nullable=False),
    sa.Column('list_id', sa.Integer(), nullable=False),
    sa.Column('calculated_at', sa.DateTime(timezone=True), server_default=sa.text('now()'), nullable=False),
    sa.Column('calculated_by_id', sa.Integer(), nullable=False),
    sa.Column('total_amount', sa.Numeric(precision=10, scale=2), nullable=False),
    sa.Column('participants', sa.ARRAY(sa.Integer()), nullable=False),
    sa.Column('split_type', sa.Enum('equal', name='splittypeenum'), nullable=False),
    sa.Column('is_settled', sa.Boolean(), nullable=False),
    sa.ForeignKeyConstraint(['calculated_by_id'], ['users.id'], ),
    sa.ForeignKeyConstraint(['list_id'], ['lists.id'], ),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_index(op.f('ix_expense_records_id'), 'expense_records', ['id'], unique=False)
    op.create_index(op.f('ix_expense_records_list_id'), 'expense_records', ['list_id'], unique=False)
    op.create_table('expense_shares',
    sa.Column('id', sa.Integer(), nullable=False),
    sa.Column('expense_record_id', sa.Integer(), nullable=False),
    sa.Column('user_id', sa.Integer(), nullable=False),
    sa.Column('amount_owed', sa.Numeric(precision=10, scale=2), nullable=False),
    sa.Column('is_paid', sa.Boolean(), nullable=False),
    sa.ForeignKeyConstraint(['expense_record_id'], ['expense_records.id'], ondelete='CASCADE'),
    sa.ForeignKeyConstraint(['user_id'], ['users.id'], ),
    sa.PrimaryKeyConstraint('id'),
    sa.UniqueConstraint('expense_record_id', 'user_id', name='uq_expense_share_user')
    )
    op.create_index(op.f('ix_expense_shares_expense_record_id'), 'expense_shares', ['expense_record_id'], unique=False)
    op.create_index(op.f('ix_expense_shares_id'), 'expense_shares', ['id'], unique=False)
    op.create_index(op.f('ix_expense_shares_user_id'), 'expense_shares', ['user_id'], unique=False)
    op.create_table('settlement_activities',
    sa.Column('id', sa.Integer(), nullable=False),
    sa.Column('expense_record_id', sa.Integer(), nullable=False),
    sa.Column('payer_user_id', sa.Integer(), nullable=False),
    sa.Column('affected_user_id', sa.Integer(), nullable=False),
    sa.Column('activity_type', sa.Enum('marked_paid', 'marked_unpaid', name='settlementactivitytypeenum'), nullable=False),
    sa.Column('timestamp', sa.DateTime(timezone=True), server_default=sa.text('now()'), nullable=False),
    sa.ForeignKeyConstraint(['affected_user_id'], ['users.id'], ),
    sa.ForeignKeyConstraint(['expense_record_id'], ['expense_records.id'], ondelete='CASCADE'),
    sa.ForeignKeyConstraint(['payer_user_id'], ['users.id'], ),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_index(op.f('ix_settlement_activities_expense_record_id'), 'settlement_activities', ['expense_record_id'], unique=False)
    op.create_index(op.f('ix_settlement_activities_id'), 'settlement_activities', ['id'], unique=False)
    op.add_column('items', sa.Column('price_added_by_id', sa.Integer(), nullable=True))
    op.add_column('items', sa.Column('price_added_at', sa.DateTime(timezone=True), nullable=True))
    op.create_foreign_key(None, 'items', 'users', ['price_added_by_id'], ['id'])
    # ### end Alembic commands ###


def downgrade() -> None:
    """Downgrade schema."""
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_constraint(None, 'items', type_='foreignkey')
    op.drop_column('items', 'price_added_at')
    op.drop_column('items', 'price_added_by_id')
    op.drop_index(op.f('ix_settlement_activities_id'), table_name='settlement_activities')
    op.drop_index(op.f('ix_settlement_activities_expense_record_id'), table_name='settlement_activities')
    op.drop_table('settlement_activities')
    op.drop_index(op.f('ix_expense_shares_user_id'), table_name='expense_shares')
    op.drop_index(op.f('ix_expense_shares_id'), table_name='expense_shares')
    op.drop_index(op.f('ix_expense_shares_expense_record_id'), table_name='expense_shares')
    op.drop_table('expense_shares')
    op.drop_index(op.f('ix_expense_records_list_id'), table_name='expense_records')
    op.drop_index(op.f('ix_expense_records_id'), table_name='expense_records')
    op.drop_table('expense_records')
    # ### end Alembic commands ###
