// src/lib/schemas/expense.ts

import type { UserPublic } from './user'; // Import UserPublic type

// --- Enums (Match backend Enum values) ---

export enum SplitTypeEnum {
    EQUAL = "equal",
    // CUSTOM = "custom" // Add later if needed
}

export enum SettlementActivityTypeEnum {
    MARKED_PAID = "marked_paid",
    MARKED_UNPAID = "marked_unpaid",
}

// --- Interfaces ---

// Represents a single user's share of an expense
export interface ExpenseSharePublic {
    id: number;
    expense_record_id: number;
    user_id: number;
    amount_owed: number; // Use number for frontend simplicity (or Decimal type)
    is_paid: boolean;
    user?: UserPublic | null; // Include user details for display
}

// Represents a log of settlement actions
export interface SettlementActivityPublic {
    id: number;
    expense_record_id: number;
    payer_user_id: number; // Who marked it paid/unpaid
    affected_user_id: number; // Whose share status changed
    activity_type: SettlementActivityTypeEnum; // Use the Enum/string literal
    timestamp: string; // ISO date string
    // Optionally include nested user details if backend provides them
    // payer?: UserPublic | null;
    // affected_user?: UserPublic | null;
}

// Represents a finalized expense split record for a list
export interface ExpenseRecordPublic {
    id: number;
    list_id: number;
    calculated_at: string; // ISO date string
    calculated_by_id: number;
    total_amount: number; // Use number for frontend simplicity (or Decimal type)
    split_type: SplitTypeEnum; // Use the Enum/string literal
    is_settled: boolean;
    participants: number[]; // List of user IDs who participated
    shares: ExpenseSharePublic[]; // Include the individual shares
    settlement_activities: SettlementActivityPublic[]; // Include settlement history
}

// Schema for the request body of the settle endpoint
export interface SettleShareRequest {
    affected_user_id: number; // The ID of the user whose share is being settled
}