// src/routes/(app)/+layout.ts
import { redirect } from '@sveltejs/kit';
import { browser } from '$app/environment';
import { get } from 'svelte/store'; // Import get for synchronous access in load
import { authStore } from '$lib/stores/authStore';
import type { LayoutLoad } from './$types'; // Import generated types for load function

export const load: LayoutLoad = ({ url }) => {
    // IMPORTANT: localStorage/authStore logic relies on the browser.
    // This check prevents errors during SSR or prerendering.
    if (!browser) {
        // On the server, we cannot reliably check auth state stored in localStorage.
        // You might implement server-side session checking here later if needed.
        // For now, we allow server rendering to proceed, the client-side check
        // or a subsequent navigation check will handle redirection if necessary.
        return {}; // Proceed with loading on server
    }

    // Get the current auth state synchronously
    const authState = get(authStore);

    console.log('(app) layout load: Checking auth state', authState);

    // If not authenticated in the browser, redirect to login
    if (!authState.isAuthenticated) {
        console.log('(app) layout load: User not authenticated, redirecting to login.');
        // Construct the redirect URL, preserving the original path the user tried to access
        const redirectTo = `/login?redirectTo=${encodeURIComponent(url.pathname + url.search)}`;
        throw redirect(307, redirectTo); // Use 307 Temporary Redirect
    }

    // If authenticated, allow the layout and page to load.
    // We could return user data here if needed by the layout/pages.
    console.log('(app) layout load: User authenticated, proceeding.');
    return {
        user: authState.user // Optionally pass user data to the layout/pages
    };
};