// src/routes/(app)/lists/new/+page.ts
import { apiClient, ApiClientError } from '$lib/apiClient';
import type { GroupPublic } from '$lib/schemas/group';
import type { PageLoad } from './$types';

export interface NewListPageLoadData {
    groups: GroupPublic[];
    error?: string | null;
}

// Fetch groups needed for the dropdown in the form
export const load: PageLoad<NewListPageLoadData> = async ({ fetch }) => {
    console.log('New List page load: Fetching groups...');
    try {
        const groups = await apiClient.get<GroupPublic[]>('/v1/groups');
        return {
            groups: groups ?? [],
            error: null
        };
    } catch (err) {
        console.error('New List page load: Failed to fetch groups:', err);
        let errorMessage = 'Failed to load group data for sharing options.';
        // Handle specific errors if needed (e.g., 401 handled globally)
        if (err instanceof Error) {
            errorMessage = `Error loading groups: ${err.message}`;
        }
        return {
            groups: [],
            error: errorMessage
        };
    }
};